summaryrefslogtreecommitdiff
path: root/cogl/cogl-bitmap.h
diff options
context:
space:
mode:
authorRobert Bragg <robert@linux.intel.com>2012-04-16 14:14:10 +0100
committerRobert Bragg <robert@linux.intel.com>2012-08-06 14:27:39 +0100
commit09642a83b5f036756c7625ade7cf57358396baec (patch)
tree9eede7db7022ece69e2ab532e283c683b9792b9e /cogl/cogl-bitmap.h
parent097d282b324df663e275e1f65ea7b6c65bab87fc (diff)
downloadcogl-09642a83b5f036756c7625ade7cf57358396baec.tar.gz
Removes all remaining use of CoglHandle
Removing CoglHandle has been an on going goal for quite a long time now and finally this patch removes the last remaining uses of the CoglHandle type and the cogl_handle_ apis. Since the big remaining users of CoglHandle were the cogl_program_ and cogl_shader_ apis which have replaced with the CoglSnippets api this patch removes both of these apis. Reviewed-by: Neil Roberts <neil@linux.intel.com> (cherry picked from commit 6ed3aaf4be21d605a1ed3176b3ea825933f85cf0) Since the original patch was done after removing deprecated API this back ported patch doesn't affect deprecated API and so actually this cherry-pick doesn't remove all remaining use of CoglHandle as it did for the master branch of Cogl.
Diffstat (limited to 'cogl/cogl-bitmap.h')
-rw-r--r--cogl/cogl-bitmap.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/cogl/cogl-bitmap.h b/cogl/cogl-bitmap.h
index e2e2962c..e13d2c82 100644
--- a/cogl/cogl-bitmap.h
+++ b/cogl/cogl-bitmap.h
@@ -239,17 +239,17 @@ cogl_bitmap_get_size_from_file (const char *filename,
/**
* cogl_is_bitmap:
- * @handle: a #CoglHandle for a bitmap
+ * @object: a #CoglObject pointer
*
* Checks whether @handle is a #CoglHandle for a bitmap
*
* Return value: %TRUE if the passed handle represents a bitmap,
* and %FALSE otherwise
*
* Since: 1.0
*/
gboolean
-cogl_is_bitmap (CoglHandle handle);
+cogl_is_bitmap (void *object);
/**
* COGL_BITMAP_ERROR:
@@ -239,17 +239,17 @@ cogl_bitmap_get_size_from_file (const char *filename,
*
- * Checks whether @handle is a #CoglHandle for a bitmap
+ * Checks whether @object is a #CoglBitmap
*
@@ -239,17 +239,17 @@ cogl_bitmap_get_size_from_file (const char *filename,
*
- * Return value: %TRUE if the passed handle represents a bitmap,
+ * Return value: %TRUE if the passed @object represents a bitmap,
* and %FALSE otherwise
*